@@ -4,7 +4,7 @@ from typing import Any, Dict, Union
 # from thirdweb.abi.token_erc20.bytecode import bytecode as TOKEN_ERC20_BYTECODE
 # from thirdweb.abi.token_erc721.bytecode import bytecode as TOKEN_ERC721_BYTECODE
 from thirdweb.types.contract import ContractType
-from thirdweb.contracts import NFTCollection, Edition, Token, Marketplace
+from thirdweb.contracts import NFTCollection, Edition, Token, Marketplace, NFTDrop
 
 
 CONTRACTS_MAP: Dict[ContractType, Union[NFTCollection, Edition, Token]] = {
@@ -12,6 +12,7 @@ CONTRACTS_MAP: Dict[ContractType, Union[NFTCollection, Edition, Token]] = {
     Edition.contract_type: Edition,  # type: ignore
     Token.contract_type: Token,  # type: ignore
     Marketplace.contract_type: Marketplace,  # type: ignore
+    NFTDrop.contract_type: NFTDrop,  # type: ignore
 }
 
 CONTRACT_BYTECODE: Dict[ContractType, str] = {
@@ -19,6 +20,7 @@ CONTRACT_BYTECODE: Dict[ContractType, str] = {
     Edition.contract_type: "",
     Token.contract_type: "",
     Marketplace.contract_type: "",
+    NFTDrop.contract_type: "",
 }
 
 REMOTE_CONTRACT_NAME: Dict[ContractType, str] = {
@@ -26,6 +28,7 @@ REMOTE_CONTRACT_NAME: Dict[ContractType, str] = {
     Edition.contract_type: "TokenERC1155",
     Token.contract_type: "TokenERC20",
     Marketplace.contract_type: "Marketplace",
+    NFTDrop.contract_type: "DropERC721",
 }
 
 REMOTE_CONTRACT_NAME_TO_CONTRACT_TYPE: Dict[str, ContractType] = {
@@ -33,4 +36,5 @@ REMOTE_CONTRACT_NAME_TO_CONTRACT_TYPE: Dict[str, ContractType] = {
     "TokenERC1155": Edition.contract_type,
     "TokenERC20": Token.contract_type,
     "Marketplace": Marketplace.contract_type,
+    "DropERC721": NFTDrop.contract_type,
 }
