@@ -10,6 +10,7 @@ from thirdweb.abi import (
     IERC20,
     IERC721,
     IERC1155,
+    DropERC721,
 )
 from thirdweb.types.settings.metadata import ContractMetadataSchema
 
@@ -26,39 +27,30 @@ TContractABI = TypeVar(
         IERC1155,
         TWRegistry,
         TWFactory,
+        DropERC721,
     ],
 )
 
+TERC721 = TypeVar("TERC721", bound=Union[TokenERC721, DropERC721])
+
 TPrimarySaleABI = TypeVar(
     "TPrimarySaleABI",
-    bound=Union[
-        TokenERC721,
-        TokenERC1155,
-        TokenERC20,
-    ],
+    bound=Union[TokenERC721, TokenERC1155, TokenERC20, DropERC721],
 )
 
 TPlatformFeeABI = TypeVar(
     "TPlatformFeeABI",
-    bound=Union[TokenERC721, TokenERC1155, TokenERC20, Marketplace],
+    bound=Union[TokenERC721, TokenERC1155, TokenERC20, Marketplace, DropERC721],
 )
 
 TRoyaltyABI = TypeVar(
     "TRoyaltyABI",
-    bound=Union[
-        TokenERC721,
-        TokenERC1155,
-    ],
+    bound=Union[TokenERC721, TokenERC1155, DropERC721],
 )
 
 TMetadataABI = TypeVar(
     "TMetadataABI",
-    bound=Union[
-        TokenERC721,
-        TokenERC1155,
-        TokenERC20,
-        Marketplace,
-    ],
+    bound=Union[TokenERC721, TokenERC1155, TokenERC20, Marketplace, DropERC721],
 )
 
 TContractSchema = TypeVar("TContractSchema", bound=ContractMetadataSchema)
@@ -69,3 +61,4 @@ class ContractType(Enum):
     EDITION = "edition"
     TOKEN = "token"
     MARKETPLACE = "marketplace"
+    NFT_DROP = "nft-drop"
